@@ -1,9 +1,9 @@
 package Code::Includable::Tree::FromStruct;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-14'; # DATE
+our $DATE = '2021-05-06'; # DATE
 our $DIST = 'Role-TinyCommons-Tree'; # DIST
-our $VERSION = '0.124'; # VERSION
+our $VERSION = '0.125'; # VERSION
 
 use strict;
 our $GET_PARENT_METHOD = 'parent';
@@ -87,7 +87,7 @@ Code::Includable::Tree::FromStruct - Routine to build tree object from data stru
 
 =head1 VERSION
 
-This document describes version 0.124 of Code::Includable::Tree::FromStruct (from Perl distribution Role-TinyCommons-Tree), released on 2020-04-14.
+This document describes version 0.125 of Code::Includable::Tree::FromStruct (from Perl distribution Role-TinyCommons-Tree), released on 2021-05-06.
 
 =for Pod::Coverage .+
 
@@ -107,23 +107,23 @@ L<Role::TinyCommons::Tree::FromStruct>.
 
 =head2 $GET_PARENT_METHOD => str (default: parent)
 
-The method names C<parent> can actually be customized by (locally) setting this
-variable and/or C<$SET_PARENT_METHOD>.
+The method name C<parent> to get parent can actually be customized by (locally)
+setting this variable. See also C<$SET_PARENT_METHOD>.
 
 =head2 $SET_PARENT_METHOD => str (default: parent)
 
-The method names C<parent> can actually be customized by (locally) setting this
-variable and/or C<$GET_PARENT_METHOD>.
+The method name C<parent> to set parent can actually be customized by (locally)
+setting this variable. See also C<$GET_PARENT_METHOD>.
 
 =head2 $GET_CHILDREN_METHOD => str (default: children)
 
-The method names C<children> can actually be customized by (locally) setting
-this variable and C<$SET_CHILDREN_METHOD>.
+The method name C<children> to get children can actually be customized by
+(locally) setting this variable. See also C<$SET_CHILDREN_METHOD>.
 
 =head2 $SET_CHILDREN_METHOD => str (default: children)
 
-The method names C<children> can actually be customized by (locally) setting
-this variable and C<$GET_CHILDREN_METHOD>.
+The method name C<children> to set children can actually be customized by
+(locally) setting this variable. See also C<$GET_CHILDREN_METHOD>.
 
 =head1 HOMEPAGE
 
@@ -135,7 +135,7 @@ Source repository is at L<https://github.com/perlancar/perl-Role-TinyCommons-Tre
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Role-TinyCommons-Tree>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Role-TinyCommons-TreeNode/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -146,13 +146,16 @@ feature.
 L<Role::TinyCommons::Tree::FromStruct> if you want to use the routines in this
 module via consuming role.
 
+L<Code::Includable::Tree::FromObjArray> if you want to build a tree of objects
+from a nested array of objects.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
