@@ -1,9 +1,9 @@
 package Role::TinyCommons::Tree;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-14'; # DATE
+our $DATE = '2021-05-06'; # DATE
 our $DIST = 'Role-TinyCommons-Tree'; # DIST
-our $VERSION = '0.124'; # VERSION
+our $VERSION = '0.125'; # VERSION
 
 1;
 # ABSTRACT: Roles related to object tree
@@ -20,7 +20,7 @@ Role::TinyCommons::Tree - Roles related to object tree
 
 =head1 VERSION
 
-This document describes version 0.124 of Role::TinyCommons::Tree (from Perl distribution Role-TinyCommons-Tree), released on 2020-04-14.
+This document describes version 0.125 of Role::TinyCommons::Tree (from Perl distribution Role-TinyCommons-Tree), released on 2021-05-06.
 
 =head1 DESCRIPTION
 
@@ -58,7 +58,7 @@ Source repository is at L<https://github.com/perlancar/perl-Role-TinyCommons-Tre
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Role-TinyCommons-Tree>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Role-TinyCommons-TreeNode/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -76,7 +76,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
